restore_file

Function restore_file 

pub fn restore_file(
    engine: &Engine,
    paths: &WorkspacePaths,
    user: HostUser,
    skip: &[String],
    id: &SnapshotId,
    file: &str,
) -> Result<Restored, BackupError>
Brings file back as it was in the snapshot id, after a snapshot of how the workspace is now. The rest of the workspace is left as it is.

Errors

A file that is not a path inside the workspace, and everything restore fails for.