pub struct Entry {
pub id: SnapshotId,
pub at: i64,
pub reason: Reason,
pub changed: usize,
}Expand description
One snapshot in the list.
Fields
id: SnapshotIdIts id, which restore takes.
at: i64When it was made, in seconds since the Unix epoch.
reason: ReasonWhy it was made.
changed: usizeHow many files it changed from the one before, or of the one file asked after.