merge

Function merge 

pub fn merge(shape: McpShape, existing: Option<&str>, token: &str) -> Merged
Registers the server in the settings existing holds, in the shape of shape, for the tab whose token is token; None is a file that is not there.