parse

Function parse 

pub fn parse(line: &str) -> Result<Question, Malformed>
Reads one question.

Errors

Malformed when the line is not JSON, not an object, lacks the token or the operation, names an operation there is not, or a send lacks its tab or its text or names a kind there is not.