pub enum Refusal {
Network,
Chain,
Pace,
Denied,
}Expand description
Why a message was not taken.
Variants
Network
A tab without the network may not send to one with it.
Chain
The chain is longer than MOST_HOPS.
Pace
The sender sent MOST_PER_WINDOW messages in the last RATE_WINDOW already.
Denied
The person denied messages from this tab to that one.