pub struct Call {
pub question: Result<Question, Malformed>,
/* private fields */
}Expand description
A question that came in, and the way back to the one who asked.
Fields
question: Result<Question, Malformed>The question, or Malformed when the line was not one.
Implementations