pub enum NotListening {
Taken,
Refused(String),
}Expand description
Why a way back could not be listened for.
Variants
Taken
Another program of this machine listens on the port already.
Refused(String)
The system refused for another reason, in its own words.