pub enum FunctionDiscoveryReason {
Entry,
CrtMain,
CallTarget,
TailCall,
UserSeed,
CodePointer,
}Expand description
Why an address is believed to start a function.
Variants
Entry
CrtMain
CallTarget
TailCall
UserSeed
CodePointer
A constant code-pointer argument passed into a callee parameter that is
itself called indirectly (call [@param]). See the
propagate_code_pointer_args pass.