pub fn shared(harness: HarnessKind) -> Option<Shared>Expand description
The file harness’s login shares with its other settings, if it has one.
pub fn shared(harness: HarnessKind) -> Option<Shared>The file harness’s login shares with its other settings, if it has one.