take

Function take 

pub fn take(harness: HarnessKind, capture: &str) -> Option<Vec<String>>
The command, run in the container a login was made in, that takes the login’s keys of harness’s shared file out into the capture folder capture; None for a harness whose login is only files of its own.