pub enum MountAccess {
ReadWrite,
ReadOnly,
}Expand description
Whether a directory is mounted into the container writable or read-only.
Variants
ReadWrite
The harness may change what it finds.
ReadOnly
The harness may read, and nothing it does can change the directory.
Implementations