pub fn showing(entry: &ProviderEntry, model: &str) -> AskExpand description
The request that asks an ollama server about one model, which is where its claimed window comes from.
pub fn showing(entry: &ProviderEntry, model: &str) -> AskThe request that asks an ollama server about one model, which is where its claimed window comes from.