pub fn trial(entry: &ProviderEntry) -> AskExpand description
The request that tries the connection: the one thing that only ever goes out because the person pressed something.
pub fn trial(entry: &ProviderEntry) -> AskThe request that tries the connection: the one thing that only ever goes out because the person pressed something.