pub enum AddError {
Taken(String),
}Expand description
Why a provider could not be added or renamed.
Variants
Taken(String)
A provider of this tag is already there. Two providers of one tag would make the tag in front of a model name mean two different machines.