Space

Struct Space 

pub struct Space {
    pub name: Option<Box<str>>,
    pub word_size: usize,
    pub addr_size: usize,
    pub ty: SpaceType,
}
A named, uniformly-addressed memory region.

Each space has a word size (bytes per addressable unit) and an address size (bytes needed to hold a pointer into the space). For most RAM spaces these are 1 and 8 respectively on a 64-bit architecture.

Fields

name: Option<Box<str>>

Optional human-readable name (e.g. "ram", "register").

word_size: usize

The size of a memory location with a single address in this space, in bytes.

addr_size: usize

The size of addresses in this space, in bytes.

ty: SpaceType

The kind of this space.

Implementations

Source

impl Space

pub fn new(name: Option<&str>, word_size: usize, addr_size: usize) -> Space

Creates a new RAM space with the given name (or anonymous if None), word size, and address size.

pub fn unique(addr_size: usize) -> Space

Creates the unique space used for instruction-local p-code temporaries.

pub fn from_id<S>(src: &S, id: SpaceId) -> Identified<SpaceId, &Space>
where S: SpaceStore + ?Sized,

Builds a space reference from an id, against any SpaceStore.