pub struct WorkspaceEntry {
pub dir: PathBuf,
pub file: Option<WorkspaceFile>,
pub problems: Vec<Diagnostic>,
}Expand description
One workspace folder as it was found on disk.
Fields
dir: PathBufThe workspace’s folder.
file: Option<WorkspaceFile>What its workspace.qcode says, when the folder names a workspace at all.
problems: Vec<Diagnostic>Everything wrong with this workspace. Empty means it is whole.
Implementations