pub struct Leftover {
pub containers: Vec<String>,
pub bytes: u64,
}Expand description
The containers QCode made that are still in the old engine.
Fields
containers: Vec<String>Their names.
bytes: u64How many bytes they hold of their own, above their images.