entry

Function entry 

pub fn entry(state: &Providers) -> Option<&'static str>
The control that takes the keyboard when the screen opens, once there is one: the list, or on an empty screen its one button.