pub fn trial_of(entry: &ProviderEntry) -> AskExpand description
The request the trial would send, for anything that needs to name it outside this module.
pub fn trial_of(entry: &ProviderEntry) -> AskThe request the trial would send, for anything that needs to name it outside this module.