opened

Function opened 

pub fn opened(setup: &mut Setup) -> Command<Msg>
The work the wizard needs the moment it is shown: asking whatever the step it opens on needs, and putting the keyboard on the question.