pub fn check_engine(kind: EngineKind) -> EngineCheckExpand description
Asks kind whether it is installed and working.
Blocks on starting the engine, so it belongs on a background thread.
pub fn check_engine(kind: EngineKind) -> EngineCheckAsks kind whether it is installed and working.
Blocks on starting the engine, so it belongs on a background thread.