Switch

Struct Switch 

pub struct Switch { /* private fields */ }
The page.

Implementations

Source

impl Switch

pub fn new( (from, to): (EngineKind, EngineKind), offered: bool, user: HostUser, profiles: Vec<Profile>, finder: Finder, ) -> Self

The page for a switch from from to to, finding both engines with finder each time it looks. offered is true for the offer at start, which changes nothing until it is taken.

pub fn engines(&self) -> (EngineKind, EngineKind)

The engine switched from and the one switched to.

pub fn offered(&self) -> bool

Whether the switch is still only offered.

pub fn taken(&mut self)

The offer was taken and the application now uses the new engine.