pub enum DocumentTrouble {
Missing,
Outside,
Unreadable(String),
}Expand description
Why a document of the workspace could not be read.
Variants
Missing
There is no file there any more.
Outside
The file is a link that leads out of the workspace folder.
Unreadable(String)
What the operating system said.