update

Function update 

pub fn update(
    workspaces: &mut Workspaces,
    message: Msg,
) -> (Command<Msg>, Option<WorkspaceId>)
Applies a message of the workspaces screen, answering with the work to do and the workspace the person opened, when they opened one.