Enum RamBase Copy item path Source pub enum RamBase {
Param(u32 ),
Frame(i64 ),
Global(u64 ),
Private,
}Expand description What an effect entry’s offsets are relative to.
The pointer passed at this positional argument index of the summary
owner’s pure_reg interface (param[i] ↔ Call.args[i] lockstep).
A slot in the summary owner’s own frame : a constant offset (< 0)
from its incoming @SP. Minted only by the effect channel’s transfer
(a callee effect rebased through an own-frame-local argument), always a
write , and dropped again when transferred one level further up — the
frame dies at return, so the effect is contained.
An absolute (literal) address in real ram.
A function-private space landing: a callee effect rebased through a
call argument that is a pointer into the summary owner’s own private
(shadow/temp) space. Outward-invisible: a private-space object can
neither be observed nor aliased by any caller, so like a Frame write it
is dropped from the outward footprint.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more 🔬 This is a nightly-only experimental API. (clamp_to)
Restrict a value to a certain range.
Read more This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.