pub enum Simplified {
Value(ValueId),
Expression(Mnemonic),
}Expand description
The result of an intrinsic’s simplify hook.
Variants
Value(ValueId)
Forward all uses of the intrinsic to this existing value, e.g.
rol(x, 0) → x or ror(rol(a, c), c) → a.
Expression(Mnemonic)
Replace the intrinsic instruction with a new expression of the same
width. The mnemonic is free to be a different intrinsic (e.g.
rol(a, c) → ror(a, bits - c)) or a plain operation (e.g. an
IntBinop-rooted +).