pub struct Instruction<'str> { /* private fields */ }Expand description
A local SSA value, which is a value that is defined by an instruction and can be used by other instructions. Local values are not associated with any particular memory location.
Implementations
Sourceimpl<'str> Instruction<'str>
impl<'str> Instruction<'str>
pub fn mnemonic(&self) -> &Mnemonic
pub fn from_id<'ctx>( ctx: &'ctx Context<'str>, id: InstructionId, ) -> InstructionRef<'str, 'ctx>
pub fn from_id_mut<'ctx>( ctx: &'ctx mut Context<'str>, id: InstructionId, ) -> InstructionMutRef<'str, 'ctx>