pub struct InstructionStatement<'a, 'str, 'ctx, R = ModuleView<'ctx, 'str>>(/* private fields */);Expand description
A formattable wrapper around an instruction reference, which formats the instruction as a string with its mnemonic and operands.