pub fn sound_container(workspace: &str, tab: u64) -> StringExpand description
The container a sound of a workspace is played in while the tab tab plays it.
The dot is what no workspace id and no profile name can hold, so this name can never be the container of a profile, whatever the profile is called.