pub enum ErrorTy {
Show 13 variants
RangeOutOfBounds {
range: Range<usize>,
available: usize,
},
UnknownIdentifier(Box<str>, &'static str),
SizeMismatch {
expected: usize,
actual: usize,
},
TriedToNameLiteral,
NameAlreadyExists(Box<str>),
UnknownAddress(u64),
NonConstArgument,
MissingArgument(Box<str>),
DuplicateName(String),
DuplicateAddress(u64, ValueId),
FunctionRootAddressMismatch {
fn_addr: u64,
block_addr: u64,
},
FunctionRootMismatch {
expected: BlockId,
actual: BlockId,
},
NoRootBlock,
}Variants
RangeOutOfBounds
UnknownIdentifier(Box<str>, &'static str)
Unknown name in an expression
SizeMismatch
TriedToNameLiteral
Attempted to set a name on a literal value
NameAlreadyExists(Box<str>)
Attempted to set a name that already exists in the current scope
UnknownAddress(u64)
NonConstArgument
A macro argument is not const
MissingArgument(Box<str>)
DuplicateName(String)
A name was registered but a value with that name already exists
DuplicateAddress(u64, ValueId)
Two values were assigned to the same machine address
FunctionRootAddressMismatch
A function and it’s root block have conflicting addresses
FunctionRootMismatch
NoRootBlock
A pass was invoked on a function that has no root (entry) block.