pub struct AggregateField {
pub name: String,
pub type_id: TypeId,
pub offset: usize,
}Expand description
One field of an aggregate or struct type.
Field names are part of aggregate identity. For structural aggregates the
slots are addressed by numeric index and offset is informational (the
running byte sum); for nominal StructTypes offset is the field’s real
byte offset and is the key a Gep resolves on.
Fields
name: Stringtype_id: TypeIdoffset: usizeByte offset of this field within its containing aggregate/struct.
Implementations