pub struct Switch { /* private fields */ }Expand description
The page.
Implementations
Sourceimpl Switch
impl Switch
Sourcepub fn new(
(from, to): (EngineKind, EngineKind),
offered: bool,
user: HostUser,
profiles: Vec<Profile>,
finder: Finder,
) -> Self
pub fn new( (from, to): (EngineKind, EngineKind), offered: bool, user: HostUser, profiles: Vec<Profile>, finder: Finder, ) -> Self
The page for a switch from from to to, finding both engines with finder each time it
looks. offered is true for the offer at start, which changes nothing until it is taken.
Sourcepub fn engines(&self) -> (EngineKind, EngineKind)
pub fn engines(&self) -> (EngineKind, EngineKind)
The engine switched from and the one switched to.