pub fn entry(screen: &WorkspaceScreen) -> &'static strExpand description
The control that takes the keyboard when the screen opens: the terminal of the open tab, the
page of a blank one, or the strip’s + that opens the first tab while there is none.