pub fn leaving(screen: &WorkspaceScreen) -> Option<Leaving>Expand description
What is backed up when QCode closes with screen as it is: every workspace of the rail, or
nothing when backups are off or there is no engine to make them.
pub fn leaving(screen: &WorkspaceScreen) -> Option<Leaving>What is backed up when QCode closes with screen as it is: every workspace of the rail, or
nothing when backups are off or there is no engine to make them.