Token

Struct Token 

pub struct Token {
    pub text: String,
    pub kind: TokenKind,
    pub link: Option<Link>,
}
One contiguous run of rendered text with its semantic kind and optional link.

Concatenating the text of every token of an instruction yields exactly the instruction’s Display output.

Fields

text: Stringkind: TokenKindlink: Option<Link>