Module varnode

Module varnode 

Varnodes: named, typed memory locations used as IR operands.

A Varnode represents a specific location in a Space — it has an address, a size in bytes, and belongs to exactly one space. Varnodes are used to model processor registers, global variables, and other named memory locations. Unlike Instruction results, they are not directly SSA form: multiple instructions can read or write the same varnode’s memory location. The Varnode’s value however is a constant.

Modules

register
Processor registers.

Structs

Varnode
A named, typed reference to a specific location in a memory Space.
VarnodeId

Type Aliases

VarnodeMutRef
VarnodeRef